from flask import Flask
from flask_admin import Admin
from flask_admin.contrib.sqla import ModelView

def create_app():
    app = Flask(__name__)
    app.config.from_object('acks.default_settings')
    app.config.from_envvar('FLASK_SETTINGS_FILE')

    # Prep the database
    from acks.models import db
    app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:///../data/acks.db'
    app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False
    db.init_app(app)

    # Load our views
    from acks.views import default_views
    app.register_blueprint(default_views)

    from acks.npc.views import npc_views
    app.register_blueprint(npc_views)

    # Load our CLI commands
    from acks.commands import default_cli
    app.cli.add_command(default_cli)

    from acks.npc.commands import npc_cli
    app.cli.add_command(npc_cli)

    # Load the Admin views
    admin = Admin(app, name='acks', template_mode='bootstrap3')

    from acks.npc.models import admin_models as npc_admin_models
    for mdl in npc_admin_models:
        admin.add_view(ModelView(mdl, db.session))

    return app
